@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package Acme::Gtk2::Ex::Builder;
 BEGIN {
-  $Acme::Gtk2::Ex::Builder::VERSION = '0.007';
+  $Acme::Gtk2::Ex::Builder::VERSION = '0.008';
 }
 # ABSTRACT: Funny Gtk2 Interface Design Module
 
@@ -14,6 +14,7 @@ our @EXPORT  = qw(
     contain
     info
     on
+    prop
     set
     widget
 );
@@ -127,6 +128,16 @@ sub build (&) {
                 $self->_current->$method(@para);
             }
         };
+
+        local *_prop = sub {
+            my $prop  = shift;
+            my $value = shift;
+ 
+            my $method = "set";
+            if ($self->_current) {
+                $self->_current->$method($prop, $value);
+            }
+        };
  
         $_code->() if defined $_code;
         $self->_current_pop;
@@ -146,11 +157,13 @@ sub _warn {
 *_info   = _warn 'info';
 *_on     = _warn 'on';
 *_set    = _warn 'set';
+*_prop   = _warn 'prop';
  
 sub widget { goto &_widget }
 sub info   { goto &_info   }
 sub on     { goto &_on     }
 sub set    { goto &_set    }
+sub prop   { goto &_prop   }
 
 1;
 
@@ -165,7 +178,7 @@ Acme::Gtk2::Ex::Builder - Funny Gtk2 Interface Design Module
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -253,6 +266,9 @@ Following code create L<Gtk2::SimpleList> with
 additional C<timestamp>, C<nick> and C<message> parameter.
 See L<Gtk2> and Gtk2 API reference.
 
+    use Gtk2;
+    use Gtk2::SimpleList; # Do NOT forgot!!
+    
     my $app = build {
         widget SimpleList => contain {
             info id              => 'logviewer';
@@ -265,6 +281,26 @@ See L<Gtk2> and Gtk2 API reference.
         );
     };
 
+It also supports prebuilt widget.
+
+    my $prev_button = Gtk2::Button->new('Prev');
+    my $next_button = Gtk2::Button->new('Next');
+    my $quit_button = Gtk2::Button->new;
+    
+    my $app = build {
+        widget VBox => contain {
+            widget HBox => contain {
+                widget $prev_button;
+                widget $next_button;
+            };
+            widget $next_button => contain {
+                info packing => TRUE, TRUE, 1, 'end';
+                set  label   => 'quit';
+                on   clicked => \&quit_clicked;
+            }
+        };
+    };
+
 =head2 info
 
 This function sets additional information.
@@ -316,8 +352,8 @@ See L<Gtk2> and Gtk2 API reference.
 
 =head2 set
 
-This function sets properties for specified widget.
-Actually it is same as C<< $widget->set_xxx >>.
+This function calls C<< $widget->set_KEY(VALUE) >> function
+for specified widget.
 See L<Gtk2> and Gtk2 API reference.
 
     my $app = build {
@@ -328,16 +364,34 @@ See L<Gtk2> and Gtk2 API reference.
         };
     };
 
+=head2 prop
+
+This function sets properties for specified widget.
+Actually it is same as C<< $widget->set(KEY, VALUE) >>.
+See L<Gtk2> and Gtk2 API reference.
+
+    my $app = build {
+        widget Window => contain {
+            info id               => 'window';
+            set  position         => 'center';
+            prop title            => 'Window Example';
+            prop opacity          => 0.8;
+            prop 'default-width'  => 640;
+            prop 'default-height' => 480;
+            on   delete_event     => \&quit;
+        };
+    };
+
 =head2 contain
 
-This function is used to set attributes,
-connect signal, add additional information or
-contain children widgets.
+This function is used to set attributes, set properties,
+connect signal, add additional information or contain children widgets.
 
     my $app = build {
         widget Window => contain {
             info   ...
             set    ...
+            prop   ...
             on     ...
             widget ...
         };
